@@ -34,7 +34,7 @@
 
 #ifndef lint
 static char copyright[] =
-"$Id: conflex.c,v 1.92.2.7 2004/06/10 17:59:14 dhankins Exp $ Copyright (c) 2004 Internet Systems Consortium.  All rights reserved.\n";
+"$Id: conflex.c,v 1.92.2.9 2004/11/24 17:39:15 dhankins Exp $ Copyright (c) 2004 Internet Systems Consortium.  All rights reserved.\n";
 #endif /* not lint */
 
 #include "dhcpd.h"
@@ -303,8 +303,8 @@ static enum dhcp_token read_string (cfile)
 	int i;
 	int bs = 0;
 	int c;
-	int value;
-	int hex;
+	int value = 0;
+	int hex = 0;
 
 	for (i = 0; i < sizeof cfile -> tokbuf; i++) {
 	      again:
@@ -742,8 +742,13 @@ static enum dhcp_token intern (atom, dfv)
 			return IGNORE;
 		break;
 	      case 'k':
-		if (!strcasecmp (atom + 1, "nown"))
-			return KNOWN;
+		if (!strncasecmp (atom + 1, "nown", 4)) {
+			if (!strcasecmp (atom + 5, "-clients"))
+				return KNOWN_CLIENTS;
+			if (!atom[5])
+				return KNOWN;
+			break;
+		}
 		if (!strcasecmp (atom + 1, "ey"))
 			return KEY;
 		break;
